## 1.1.1 (2024-11-06)

### Fix

- upgrade tests

## 1.1.1rc0 (2024-11-06)

### Fix

- update tiramisu dependency
- better user information if a needed package is not installed
- **37**: import doesn't works for some python version
- **36**: format 1.0: suffix attribut must works
- update fr/rougail.mo

## 1.1.0 (2024-11-01)

### Fix

- black
- add changelog_merge_prerelease to commitizen

## 1.1.0rc0 (2024-11-01)

### Feat

- update dependencies
- translation
- in calculation better debugging
- can sort dictionaries in different directories
- suffix to identifier
- better errors messages and improvement
- better debugging
- update upgrade module
- auto add multi for leader
- use suffix in property calculation
- in structural commandline very is there is conflict alternative name
- **#21**: add examples attributes
- **#23**: define easily a regexoption
- add relative path support
- add default inference for basic types
- suffixes in dynamic family should be a jinja function (#5)
- we should be able to customize a new variable type

### Fix

- support for unknown language
- license
- README
- use black
- valid mode even if there is no mode configured
- valid mode if no mode defined
- update tests
- type is not always mandatory
- auto_save in follower is now allowed in tiramisu

## 1.0.2 (2024-01-28)

### Fix

- 2023 => 2024
- correction for calculated variable with a variable in a dynamic family

## 1.0.1 (2024-01-28)

### Feat

- documentation
- new format 1.0
